@@ -1,19 +1,20 @@
 # Naming conventions
-FRAMEWORK_NAME = 'investing investing_algorithm_framework framework'
+FRAMEWORK_NAME = 'investing_algorithm_framework'
 FRAMEWORK_CORE_MODULE_NAME = 'investing_algorithm_framework.core'
-
-# Setting related constants
-SETTINGS_ALGORITHM_PROJECT_NAME = 'ALGORITHM_PROJECT_NAME'
 SETTINGS_MODULE_PATH_ENV_NAME = 'INVESTING_ALGORITHM_FRAMEWORK_SETTINGS_MODULE'
-SETTINGS_DATA_PROVIDER_REGISTERED_APPS = 'INSTALLED_DATA_PROVIDER_APPS'
-SETTINGS_STRATEGY_REGISTERED_APPS = 'INSTALLED_STRATEGY_APPS'
-SETTINGS_MAX_WORKERS = 'DEFAULT_MAX_WORKERS'
+
+# Project related constants
+BASE_DIR = 'BASE_DIR'
+SETTINGS_PROJECT_NAME = 'PROJECT_NAME'
+SETTINGS_MAX_CONCURRENT_WORKERS = 'MAX_CONCURRENT_WORKERS'
 SETTINGS_CONTEXT_CONFIGURATION = 'CONTEXT_CONFIGURATION'
 SETTINGS_LOGGING_CONFIG = 'LOGGING'
 
-# Operational constants
-DEFAULT_MAX_WORKERS = 2
-
 # Database related constants
-BASE_DIR = 'BASE_DIR'
+DATABASE_CONFIG = 'DATABASE_CONFIG'
 DATABASE_NAME = 'DATABASE_NAME'
+DATABASE_TYPE = 'DATABASE_TYPE'
+DATABASE_DIRECTORY_PATH = 'DATABASE_DIRECTORY_PATH'
+DATABASE_URL = 'DATABASE_URL'
+
+DEFAULT_MAX_WORKERS = 2
