@@ -1,5 +1,3 @@
-import sys
-from threading import Thread
 from wrapt import synchronized
 from enum import Enum
 
@@ -25,42 +23,6 @@ class Singleton(type):
         return cls._instances[cls]
 
 
-class StoppableThread(Thread):
-    """
-    Class StoppableThread: Functions as a wrapper around a thread to add
-    stop function
-    """
-
-    def __init__(self, *args, **keywords):
-        Thread.__init__(self, *args, **keywords)
-        self.killed = False
-
-    def start(self):
-        self.__run_backup = self.run
-        self.run = self.__run
-        Thread.start(self)
-
-    def __run(self):
-        sys.settrace(self.globaltrace)
-        self.__run_backup()
-        self.run = self.__run_backup
-
-    def globaltrace(self, frame, event, arg):
-        if event == 'call':
-            return self.localtrace
-        else:
-            return None
-
-    def localtrace(self, frame, event, arg):
-        if self.killed:
-            if event == 'line':
-                raise SystemExit()
-        return self.localtrace
-
-    def kill(self):
-        self.killed = True
-
-
 class TimeUnit(Enum):
     """
     Class TimeUnit: Enum for TimeUnit
